core.wrds_update_schema

core.wrds_update_schema(schema, *, data_dir=None, threads=3, archive=False)

Update existing parquet files in a schema.

Parameters

Name Type Description Default
schema str Name of database schema. required
data_dir str Root directory of parquet data repository. If not provided, defaults to the value of the DATA_DIR environment variable, or the current directory. None
threads int The number of threads DuckDB is allowed to use. 3
archive bool Whether any existing parquet file will be archived. False

Returns

Name Type Description
pq_files list[str] Names of parquet files updated.