files.paths.pq_list_files

files.paths.pq_list_files(
    schema,
    *,
    data_dir=None,
    archive=False,
    archive_dir=None,
)

Get a list of parquet files in a schema or its archive directory.

For workflow-oriented examples, see Parquet Utilities Examples.

Parameters

Name Type Description Default
schema Name of database schema. required
data_dir str Root directory of the parquet data repository. If not provided, defaults to the value of the DATA_DIR environment variable or the current working directory. None
archive bool If True, list files in the archive directory under the schema. False
archive_dir str Name of the archive directory under the schema directory. Defaults to "archive". None

Returns

Name Type Description
list[str] Names of parquet files found.